@@ -3,8 +3,6 @@ setMethod("angleSummary",
           signature=".MoveTrackSingle",
           definition=function(x){
             if(nrow(coordinates(x))>=3){
-              if(!require(geosphere))
-                stop("You need to install the geosphere package to proceed")
               if (!require(circular)) 
                 stop("You need to install the circular package to proceed") #var.circular
               if (!grepl("longlat",proj4string(x))) x <- spTransform(x, CRSobj="+proj=longlat")
@@ -28,8 +26,6 @@ setMethod("angle",
           signature=".MoveTrackSingle",
           definition=function(x){
             if(nrow(coordinates(x))>=3){
-              if(!require(geosphere))
-                stop("You need to install the geosphere package to proceed")
               if (!isLonLat(x)) x <- spTransform(x, CRSobj="+proj=longlat")
               tAzimuth <- geosphere::bearing(coordinates(x)[-n.locs(x), ], coordinates(x)[-1, ])
               return(tAzimuth)} else {NA}
